# Pyh2m for Scrapy Pipeline

------------
settings.py:

```python
...
# pyh2m settings for crawler project
RAW_TEXT = True  # raw text or markdown text
HTML_DICT_NAME = "html"        # item["html"]
MARK_DICT_NAME = "markdown"    # item["markdown"]
...
```